@@ -26,17 +26,20 @@ public:
 public Q_SLOTS:
     void load() override;
     void save() override;
+    void defaults() override;
 
 private Q_SLOTS:
     void updateForgetDeviceButton();
     void forgetSelectedDevices();
+    void updateState();
 
 private:
     void saveLayout();
     void loadLayout();
 
-    AutomounterSettings *m_settings;
-    DeviceModel *m_devices;
+    AutomounterSettings *const m_settings;
+    DeviceModel *const m_devices;
+    bool m_unmanagedChanges = false;
 };
 
 #endif
